@@ -55,7 +55,6 @@ class UploadQueueItem:
         self.transaction_id = transaction_id  # ID of the transaction
 
     def upload_blocking(self, mc, mp):
-
         with open(self.file_path, "rb") as file_handle:
             file_handle.seek(self.chunk_index * UPLOAD_CHUNK_SIZE)
             data = file_handle.read(UPLOAD_CHUNK_SIZE)
@@ -133,14 +132,6 @@ def push_project_async(mc, directory):
         if mp.is_versioned_file(f["path"]):
             mp.copy_versioned_file_for_upload(f, tmp_dir.name)
 
-    # currently proceed storage limit check only if a project is own by a current user.
-    if username == project_path.split("/")[0]:
-        enough_free_space, freespace = mc.enough_storage_available(changes)
-        if not enough_free_space:
-            freespace = int(freespace / (1024 * 1024))
-            mp.log.error(f"--- push {project_path} - not enough space")
-            raise ClientError("Storage limit has been reached. Only " + str(freespace) + "MB left")
-
     if not sum(len(v) for v in changes.values()):
         mp.log.info(f"--- push {project_path} - nothing to do")
         return
@@ -283,6 +274,7 @@ def push_project_finalize(job):
     job.mp.metadata = {
         "name": job.project_path,
         "version": job.server_resp["version"],
+        "project_id": job.server_resp["id"],
         "files": job.server_resp["files"],
     }
     try:
